@@ -23,6 +23,7 @@ from werkzeug.middleware.dispatcher import DispatcherMiddleware
 from .fastapi_metrics_redirect import MetricsRedirect
 from ..utils.singleton import SingletonMeta
 from ..utils.bcolor import Bcolors
+from ..utils.gunicorn_multiprocess import clear_multiproc_dir
 
 from .config import _DEFAULT_BUCKETS, _DEFAULT_LABELS, NAMESPACE, SERVICENAME
 
@@ -272,11 +273,12 @@ class PrometheusMiddleware(metaclass=SingletonMeta):
         """
 
         if self.is_multiprocessing:
-            MULTIPROC_DIR = os.environ["PROMETHEUS_MULTIPROC_DIR"]
-            if MULTIPROC_DIR:
-                file_path = Path(MULTIPROC_DIR)
-                if not os.path.isdir(file_path):
-                    os.mkdir(file_path)
+            clear_multiproc_dir()
+            # MULTIPROC_DIR = os.environ["PROMETHEUS_MULTIPROC_DIR"]
+            # if MULTIPROC_DIR:
+            #     file_path = Path(MULTIPROC_DIR)
+            #     if not os.path.isdir(file_path):
+            #         os.mkdir(file_path)
 
             @self.app.route("/metrics", methods=["GET"])
             def metrics():
